@@ -1,4 +1,4 @@
-def maximum_product_subarray(self, nums):
+def maximum_product_subarray(nums):
     i = 0
     currentMax, currentMin, ans = nums[0], nums[0], nums[0]
     for i in range(1, len(nums)):
